@@ -1,6 +1,8 @@
 import os
+import time
+import random
 
-from sbdk.docker import make_runner, make_client
+from sbdk.docker import make_runner, make_client, find_image
 from sbdk.executor import Adun
 from sbdk.error import SbdkError
 from sbgsdk.job import Job
@@ -17,11 +19,6 @@ def argument_parser(subparsers):
     parser.add_argument("--image-tag", help="Docker image tag", type=str, required=True)
 
 
-def find_image(client, image_id):
-    images = client.images()
-    return (filter(lambda x: x['Id'].startswith(image_id), images) or [None])[0]
-
-
 def run(project, job, image_repo, image_tag, result):
     assert project and job and image_tag and image_repo and result, 'All arguments required.'
     job_file_path = job
@@ -30,10 +27,11 @@ def run(project, job, image_repo, image_tag, result):
         assert isinstance(job, Job), "Expected Job in %s" % job_file_path
 
     docker_client = make_client(project)
-    image = find_image(docker_client, image_tag)
+    image = find_image(docker_client, image_repo, image_tag)
     if not image:
         docker_client.pull(image_repo, image_tag)
-        image = find_image(docker_client, image_tag)
+        time.sleep(1+random.random()*10)  # Weird stuff happening on simultaneous pull + run.
+        image = find_image(docker_client, image_repo, image_tag)
     if not image:
         raise SbdkError('Image not found: %s tag: %s' % (image_repo, image_tag))
     os.chdir(project.project_dir)
