@@ -27,7 +27,8 @@ def push(project, message):
         print "Error while preparing image:"
         container.print_log()
         exit("Push command failed")
-    config = {'Entrypoint': project.sdk_runner_command}
+    config = {'Cmd': project.sdk_runner_command, 'Entrypoint': ['/sbin/my_init', '--quiet', '--']}
+    container.load_credentials(renew=True)
     container.commit(message, config).push()
     push_schema(project, container)
     container.remove()
