@@ -4,6 +4,8 @@ import shlex
 from pipes import quote
 
 from sbdk.docker.container import Container
+from sbdk.docker.utils import find_image, parse_repository_tag
+from docker.client import APIError
 from sbgsdk.util import handle_signal
 
 
@@ -21,22 +23,34 @@ class Runner(object):
         self.image_id = project.image_id
         self.dns = project.docker_dns
         self.docker_config = kwargs
-        self.entrypoint = project.docker_entrypoint
+        #self.entrypoint = project.docker_entrypoint
 
     def run(self, command):
         volumes = {'/sb': {}, Runner.WORKING_DIR: {}}
         binds = {self.sb_dir: "/sb:rw",
                  self.working_dir: Runner.WORKING_DIR + ":rw"}
-        logging.debug("Running command %s", command)
+        logging.debug("Running command %s" % command)
         config = make_config(self.image_id, command)
         config['Volumes'] = volumes
         config['WorkingDir'] = Runner.WORKING_DIR
         config['Dns'] = self.dns
-        config['Entrypoint'] = self.entrypoint
+        #config['Entrypoint'] = self.entrypoint
 
         config.update(self.docker_config)
 
-        cont = self.client.create_container_from_config(config)
+        try:
+            cont = self.client.create_container_from_config(config)
+        except APIError as e:
+            # 404 means image was not found
+            if e.response.status_code == 404:
+                logging.info("Trying to fetch image %s" % self.image_id)
+                repo, tag = parse_repository_tag(self.image_id)
+                self.client.pull(repo, tag)
+                self.image_id = find_image(self.client, repo, tag)
+                config['Image'] = self.image_id
+                cont = self.client.create_container_from_config(config)
+            else:
+                raise
         self.client.start(container=cont, binds=binds)
 
         return Container(self.client, self.project, cont)
@@ -95,15 +109,18 @@ class ImageRunner(Runner):
 
     def __init__(self, docker_client, project, **kwargs):
         Runner.__init__(self, docker_client, project, **kwargs)
+        image_id = project.image_id
+        info = docker_client.inspect_image(image_id)
+        self.base_cmd = info['config']['Cmd']
 
     def run_wrapper(self, input_path, cwd=None):
-        run_full = ['run-full', '-i', input_path]
+        run_full = self.base_cmd + ['run-full', '-i', input_path]
         if cwd:
             run_full += ['--cwd', cwd]
         self.run_and_print(run_full)
 
     def run_job(self, input_path, output_path, cwd=None):
-        run = ['run', '-i', input_path, '-o', output_path]
+        run = self.base_cmd + ['run', '-i', input_path, '-o', output_path]
         if cwd:
             run += ['--cwd', cwd]
         self.run_and_print(run)
@@ -115,8 +132,8 @@ class ImageRunner(Runner):
         raise NotImplementedError("Method 'run_install' not implemented for class ImageRunner.")
 
     def schema(self, output=None):
-        name = self.project.name
-        cmd = ['schema'] + (['--package', name] if name else [])
+        name = self.project.name if self.project else None
+        cmd = self.base_cmd + ['schema'] + (['--package', name] if name else [])
         cmd += ['--output', output] if output else []
         self.run_and_print(cmd)
 
@@ -139,3 +156,6 @@ def multi_command(*args):
 
 def shell_join(args):
     return ' '.join([quote(s) for s in args])
+
+
+
