@@ -3,6 +3,8 @@ import keyword
 import os
 import re
 import stat
+import random
+import time
 from os.path import join, isdir, dirname, basename, abspath, isfile
 
 import sbdk.resources as resources
@@ -13,7 +15,7 @@ from sbdk import VERSION
 
 DEFAULT_CONFIG = {
     'version': VERSION,
-    'default_base_image': 'sevenbridges/sdkbase',
+    'default_base_image': 'sevenbridges/sdkbase:beta',
     'logging_config': 'logging.json',
 
     'shell_type': 'bash',
@@ -27,8 +29,8 @@ DEFAULT_CONFIG = {
     'docker_registry_version': '1',
     'docker_registry_schema': 'http',
     'docker_daemon_url': 'unix://var/run/docker.sock',
-    'docker_protocol_version': '1.6',
-    'docker_user': 'wrapper',
+    'docker_protocol_version': '1.8',
+    'docker_user': 'sbg',
     'docker_dns': None,
     'docker_entrypoint': None
 }
@@ -37,7 +39,7 @@ DEFAULT_CONFIG = {
 class Project(object):
     def __init__(self, context=None):
         context = context or {}
-        self.sb_home = os.path.expanduser('~/.sb')
+        self.sb_home = os.path.expanduser('~/.sbg')
         self._prepare_home_dir()
 
         pd = context.get('project_dir')
@@ -130,22 +132,28 @@ class Project(object):
             raise AttributeError("%r object has no attribute %r" %
                                 (self.__class__.__name__, item))
 
-    def _prepare_home_dir(self):
-        if not os.path.exists(self.sb_home):
-            os.mkdir(self.sb_home)
+    def _prepare_home_dir(self, retries=5):
+        try:
+            if not os.path.exists(self.sb_home):
+                os.mkdir(self.sb_home)
 
-        cache_path = join(self.sb_home, 'pip_cache')
-        utils_path = join(self.sb_home, 'utils')
+            cache_path = join(self.sb_home, 'pip_cache')
+            utils_path = join(self.sb_home, 'utils')
 
-        for p in cache_path, utils_path:
-            if not os.path.exists(p):
-                os.mkdir(p)
+            for p in cache_path, utils_path:
+                if not os.path.exists(p):
+                    os.mkdir(p)
 
-        resources.copy('fix-uid.sh', utils_path)
-        fix_uid = join(utils_path, 'fix-uid.sh')
-        mod = os.stat(fix_uid).st_mode
-        plus_x = stat.S_IXGRP | stat.S_IXUSR | stat.S_IXOTH
-        os.chmod(fix_uid, mod | plus_x)
+            resources.copy('fix-uid.sh', utils_path)
+            fix_uid = join(utils_path, 'fix-uid.sh')
+            mod = os.stat(fix_uid).st_mode
+            plus_x = stat.S_IXGRP | stat.S_IXUSR | stat.S_IXOTH
+            os.chmod(fix_uid, mod | plus_x)
+        except OSError:
+            if retries:
+                time.sleep(random.random())
+                return self._prepare_home_dir(retries-1)
+            raise
 
     def _create_context(self, context=None):
         result = dict(DEFAULT_CONFIG)
